@@ -44,7 +44,7 @@ class Profile:
         except TypeError:
             hot_pixel_threshold = [hot_pixel_threshold] * len(file_paths)
         for i, f in enumerate(file_paths):
-            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold, transpose=transpose))
+            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold[i], transpose=transpose))
         self.q_vectors = None
         self.reflected_intensity = None
 
@@ -330,7 +330,7 @@ class Scan:
                 if self.data['roi1_maxval'][i] > self.pixel_max:
                     to_remove.append(i)
                     continue
-                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold[i], transpose=self.transpose)
+                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold, transpose=self.transpose)
                 if crop_kwargs is None:
                     im.crop(crop_function)
                 else:
